pub struct ConstInputGate<F: Field> {
data_node: NodeRef<F>,
bits_mle: MultilinearExtension<F>,
constant_name: String,
}Expand description
Represents a constant input to the circuit. Unlike other gates, the ConstInputGate takes as input a name for the constant and its value and creates an input shred as well the MLE of input data that can be bound to the circuit at a later time.
Fields
data_node: NodeRef<F>bits_mle: MultilinearExtension<F>constant_name: StringImplementations
Sourceimpl<F: Field> ConstInputGate<F>
impl<F: Field> ConstInputGate<F>
Sourcepub fn new<T>(
builder_ref: &mut CircuitBuilder<F>,
constant_name: &str,
constant_value: T,
) -> Self
pub fn new<T>( builder_ref: &mut CircuitBuilder<F>, constant_name: &str, constant_value: T, ) -> Self
Creates a constant input gate, with name constant_name with
value constant_value. When binding to the Circuit, the same
constant_name should be used in call to Circuit::set_input()
Sourcepub fn add_to_circuit(&self, circuit: &mut Circuit<F>)
pub fn add_to_circuit(&self, circuit: &mut Circuit<F>)
Given an instantiated circuit, adds the constant gate to the circuit as input with correct input label name.
Sourcepub fn input_mle(&self) -> &MultilinearExtension<F>
pub fn input_mle(&self) -> &MultilinearExtension<F>
Returns the MLE of bit-decomposition of the constant data
Sourcepub fn get_output(&self) -> NodeRef<F>
pub fn get_output(&self) -> NodeRef<F>
Returns the node that represents this constant. If the same constant is used in multiple places, this allows re-using the same constant input gate.
Sourcepub fn get_output_ref(&self) -> &NodeRef<F>
pub fn get_output_ref(&self) -> &NodeRef<F>
Returns the constant gate nodes